"use client";

/**
 * 天气信息组件
 * 包含当前天气和天气预报展示
 */

import { FC } from "react";
import { WeatherData } from "../types/magic-mirror";
import WbSunnyIcon from "@mui/icons-material/WbSunny";

interface WeatherSectionProps {
  data: WeatherData;
}

const WeatherSection: FC<WeatherSectionProps> = ({ data }) => {
  return (
    <>
      {/* 当前天气模块 */}
      <div className="absolute top-8 right-0 w-64 space-y-4">
        <div className="grid grid-cols-2 gap-4 text-sm">
          <div className="space-y-1">
            <div className="text-gray-400">风速</div>
            <div className="text-gray-300">
              {data.windSpeed}km/h {data.windDirection}
            </div>
          </div>
          <div className="space-y-1">
            <div className="text-gray-400">日出/日落</div>
            <div className="text-gray-300">
              {data.sunrise} / {data.sunset}
            </div>
          </div>
        </div>

        <div className="flex items-center gap-4">
          <div className="text-4xl">☀️</div>
          <div>
            <div className="text-3xl">{data.temp}°C</div>
            <div className="text-gray-400 text-sm">体感 {data.feelsLike}°C</div>
          </div>
        </div>

        <div className="space-y-2">
          <div className="text-gray-400 text-sm">紫外线指数</div>
          <div className="text-gray-300">{data.uvIndex}</div>
        </div>
      </div>

      {/* 天气预报模块 */}
      <div className="absolute top-64 right-8 w-64 space-y-2">
        {data.forecast.map((day, index) => (
          <div
            key={day.day}
            className="flex justify-between text-sm"
            style={{ opacity: 1 - index * 0.15 }}
          >
            <div className="text-gray-300">{day.day}</div>
            <div className="text-gray-400">{day.condition}</div>
            <div className="text-gray-300">
              {day.low}° {day.high}°
            </div>
          </div>
        ))}
      </div>
    </>
  );
};

export default WeatherSection;
